@@ -1,11 +1,12 @@
-from .base import Anchor, Link, MdObj, MdSeq, Paragraph, Raw
+from .base import Anchor, Link, MdObj, MdSeq, Paragraph, Raw, comment
 from .combo import HLine
 from .containers import Admonition, Code, CodeFile, Tab
 from .docstring import Docstring
 from .file import File
 from .header import H1, H2, H3, H4, H5, H6, H7, Heading
 from .idstore import IDStore
-from .image import PIL, Altair, Image, ImageFile, Plotly
+from .image import (PIL, Altair, ImageFile, Matplotlib, Plotly, Plotnine,
+                    Seaborn)
 from .list import List
 from .md_proxy import MdProxy, register_md
 from .settings import PageInfo, Settings, merge_settings
@@ -22,6 +23,7 @@ __all__ = [
     "Paragraph",
     "P",
     "Raw",
+    "comment",
     "HLine",
     "Admonition",
     "Code",
@@ -40,7 +42,9 @@ __all__ = [
     "IDStore",
     "PIL",
     "Altair",
-    "Image",
+    "Matplotlib",
+    "Plotnine",
+    "Seaborn",
     "ImageFile",
     "Plotly",
     "List",
